summaryrefslogtreecommitdiffhomepage
path: root/packages/core/tests/tools
diff options
context:
space:
mode:
Diffstat (limited to 'packages/core/tests/tools')
-rw-r--r--packages/core/tests/tools/send-to-tab.test.ts4
1 files changed, 2 insertions, 2 deletions
diff --git a/packages/core/tests/tools/send-to-tab.test.ts b/packages/core/tests/tools/send-to-tab.test.ts
index 48ff460..21d8032 100644
--- a/packages/core/tests/tools/send-to-tab.test.ts
+++ b/packages/core/tests/tools/send-to-tab.test.ts
@@ -38,8 +38,8 @@ describe("createSendToTabTool — schema & description", () => {
it("never mentions read_tab in the description when canReadTab is false", () => {
const tool = createSendToTabTool(makeCallbacks({ canReadTab: false }));
expect(tool.description).not.toContain("read_tab");
- // Still tells the agent a reply arrives on its own + to end its turn.
- expect(tool.description.toLowerCase()).toContain("arrives on its own");
+ // Still tells the agent a reply will wake it + to end its turn.
+ expect(tool.description.toLowerCase()).toContain("wake you with a new message");
expect(tool.description.toLowerCase()).toContain("end your turn");
});
});